function [nmax,nmin] = narb(l)

%function narb 
%refractive indices for arbitrary directions

%uses: [abc]fitparas.dat

load afitparas.dat;
load bfitparas.dat;
load cfitparas.dat;

na = nsquare(l,afitparas);
nb = nsquare(l,bfitparas);
nc = nsquare(l,cfitparas);

global angle;

[phi, theta] = meshgrid(angle);

cp = cos(phi*pi/180);
sp = sin(phi*pi/180);
ct = cos(theta*pi/180);
st = sin(theta*pi/180);

A = sp.*sp/na + cp.*cp/nb;
B = sp.*cp.*st*(1/na-1/nb);
C = cp.*cp.*st.*st/na + sp.*sp.*st.*st/nb + ct.*ct/nc;

p = (C-A)./B/2;

epsilon = atan(p + sqrt(p.*p+1));

ce = cos(epsilon);
se = sin(epsilon);

n1 = 1./(ce.*ce.*A + 2*se.*ce.*B + se.*se.*C);
n2 = 1./(se.*se.*A - 2*se.*ce.*B + ce.*ce.*C);

nmax = sqrt(max(n1,n2));
nmin = sqrt(min(n1,n2));

% helper function

function nn = nsquare(l,x)
nn = x(1)/(1/x(2)/x(2)-1/l/l)+1;

